pub enum ExitTarget {
Label {
paragraph: u32,
owner: u64,
at: Pos,
},
Program {
name: String,
commarea: Option<(usize, i16)>,
},
}Variants
Label
A paragraph of the program activation owner that set the exit, entered as by a GO TO at
the HANDLE ABEND command at.
Program
A program, entered as by LINK with the COMMAREA and EIBCALEN of the program that set the exit, when it had a COMMAREA.