pub fn de_edit(syms: &[Sym], text: &str, currency: &str) -> (bool, u128)Expand description
A numeric-edited item’s value: the digits in its digit positions, negative when it shows a
minus sign, CR or DB. currency is the currency sign value, as for [numeric].