pub struct Journal {
pub id: String,
pub path: PathBuf,
pub executor: Option<&'static str>,
pub assumptions: Option<Vec<&'static str>>,
/* private fields */
}Fields
id: Stringpath: PathBufexecutor: Option<&'static str>Which ran the program, vm or interpreter, for the close record.
assumptions: Option<Vec<&'static str>>The ids of the register’s assumptions the run could have rested on, in byte order, for the close record; None for a command that ran no program.
Implementations