pub fn compile_time() -> Result<CompileTime, String>Expand description
When a compile happens: SOURCE_DATE_EPOCH’s seconds when the build sets it, the reproducible-builds convention, and the clock otherwise.
pub fn compile_time() -> Result<CompileTime, String>When a compile happens: SOURCE_DATE_EPOCH’s seconds when the build sets it, the reproducible-builds convention, and the clock otherwise.