pub enum Kind {
Show 14 variants
Group,
Alnum {
justified: bool,
},
National,
Dbcs {
justified: bool,
edit: Option<u32>,
},
Zoned {
digits: u32,
scale: u32,
signed: bool,
sign: Option<SignClause>,
},
Packed {
digits: u32,
scale: u32,
signed: bool,
},
Binary {
digits: u32,
scale: u32,
signed: bool,
native: bool,
},
Float(Precision),
NumericEdited {
edit: u32,
digits: u32,
scale: u32,
blank_when_zero: bool,
},
AlnumEdited {
edit: u32,
},
Pointer,
Index,
ObjectReference,
ProgramPointer,
}Variants
Group
Alnum
National
Dbcs
USAGE DISPLAY-1: DBCS characters, two bytes each, X’4040’ the space. edit indexes the
layout’s edited PICTUREs for one with B, a position that always holds a DBCS space.
Zoned
Packed
Binary
Float(Precision)
NumericEdited
edit indexes the layout’s list of edited PICTUREs.
AlnumEdited
Pointer
USAGE POINTER: an address, four bytes.
Index
An index name or USAGE INDEX item, holding an occurrence number in four bytes.
ObjectReference
USAGE OBJECT REFERENCE: four bytes naming an object, as under LP(32).
ProgramPointer
USAGE FUNCTION-POINTER or PROCEDURE-POINTER, four bytes.
Implementations