format

Function format 

pub fn format(
    terms: &[Term],
    f: &Fields,
    time: bool,
    page: &CodePage,
) -> Vec<u8> ⓘ
Writes a date, or a timestamp when time (CEEDATM); without it every time term is zero, as CEEDATE shows them (SA38-0683-60, Table 27).