program_arguments

Function program_arguments 

pub fn program_arguments(parm: &str) -> &str
The program arguments in parm under CBLOPTS(ON), Language Environment’s default outside CICS: what precedes the last slash, unless no word after it is a runtime option, when the whole string is (assumption C250).