pub struct Page {
pub geometry: Geometry,
pub counter: u64,
/* private fields */
}Expand description
Where the printer is on a LINAGE file’s current page.
Fields
geometry: Geometrycounter: u64LINAGE-COUNTER: the line of the page body the printer is at.
Implementations
Sourceimpl Page
impl Page
pub fn opened(geometry: Geometry) -> Page
Sourcepub fn write<E>(
&mut self,
before: bool,
motion: Motion,
next: impl FnOnce() -> Result<Geometry, E>,
) -> Result<Step, E>
pub fn write<E>( &mut self, before: bool, motion: Motion, next: impl FnOnce() -> Result<Geometry, E>, ) -> Result<Step, E>
A WRITE BEFORE (before) or AFTER ADVANCING motion. A WRITE that would pass the page
body, or that advances a page, goes to the first line of the next page, whose geometry
next gives (Language Reference SC27-8713-03, pp. 474-475).