Argument

Enum Argument 

pub enum Argument {
    Value(Comparand),
    All {
        element: u32,
        all: Vec<(u32, Count)>,
    },
}
A FUNCTION argument: one value, or the elements of a table written with ALL subscripts.

Variants



Value(Comparand)



All

element is the table as written, each ALL subscript 1. Each (position, count) is an ALL subscript’s position among the place’s subscripts and its occurrences. The counts are evaluated first, left to right; then, unless one is zero, each element with its ALL subscripts set, the rightmost varying fastest, is evaluated and read as Load reads it.

Fields

element: u32
all: Vec<(u32, Count)>