Flag

Enum Flag 

pub enum Flag {
    Set {
        on: SetTo,
        off: SetTo,
    },
    Literals {
        on: (u32, MovePlan),
        off: (u32, MovePlan),
    },
}
A USING phrase: what a true or null value sets, then what a false or other value sets.

Variants



Set

SET condition-name TO TRUE, or TO FALSE.

Fields

off: SetTo


Literals

One of two literals moved into the indicator, or the item.

Fields

off: (u32, MovePlan)