pub enum SenderCheck {
None,
Item,
Integer,
}Expand description
NUMCHECK’s test of a MOVE’s sending item, once the item is located and before it is read
(rt::store::numcheck_sender).
Variants
None
No test: no NUMCHECK, a sender that is not a data item, or a zoned sender ZON(LAX) exempts.
Item
The test Operand::Load makes of its item.
Integer
An alphanumeric or group sender moved to a numeric receiver: an unsigned integer’s digits.