pub enum UserArgument {
Reference(u32),
Value(Comparand),
}Expand description
A data item passed BY REFERENCE passes its address. Any other argument passes its value, which the function’s activation moves into a temporary its formal parameter describes (C272).
Variants