XmlValue

Enum XmlValue 

pub enum XmlValue {
    Element {
        members: Vec<u32>,
    },
    Members {
        members: Vec<u32>,
    },
    Leaf {
        form: XmlForm,
        suppress: Vec<Figurative>,
        convert: Convert,
    },
}

Variants



Element

A named group’s element: each occurrence of each member, in order.

Fields

members: Vec<u32>


Members

An unnamed group, each occurrence’s members joining the element that holds it.

Fields

members: Vec<u32>


Leaf

suppress: the item’s own WHEN constants, or when it has none each EVERY phrase’s that selects its kind and form. A value that is not legal XML goes in hexadecimal, as an element named “hex.” and the name, and XML-CODE is 417.

Fields

form: XmlForm
suppress: Vec<Figurative>
convert: Convert