pub struct AbendText {
pub code: AbendCode,
pub message: u32,
pub at: Option<u32>,
}Expand description
at is None where the op or terminator that raises the abend gives its position, and the data
entry’s for Storage.init_abend.
Fields
code: AbendCodemessage: u32at: Option<u32>Trait Implementations
impl Eq for AbendText
impl StructuralPartialEq for AbendText