pub struct Edit {
pub syms: Vec<Sym>,
pub currency: String,
}Expand description
An edited PICTURE’s symbols, and the currency sign value its currency symbol stands for, empty when it has none.
Fields
syms: Vec<Sym>currency: StringTrait Implementations
impl Eq for Edit
impl StructuralPartialEq for Edit