pub struct EntryPoint {
pub name: u32,
pub paragraph: u32,
pub block: u32,
pub using: Vec<u16>,
}Expand description
An ENTRY statement: a CALL of name starts at block, the statement after the ENTRY in
paragraph paragraph, in the Main frame, with using in place of Storage.using.
Fields
name: u32paragraph: u32block: u32using: Vec<u16>Trait Implementations
Sourceimpl Clone for EntryPoint
impl Clone for EntryPoint
Sourcefn clone(&self) -> EntryPoint
fn clone(&self) -> EntryPoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EntryPoint
impl Debug for EntryPoint
Sourceimpl Decode for EntryPoint
impl Decode for EntryPoint
fn decode(r: &mut Reader<'_>) -> Result<EntryPoint, ModuleError>
impl Eq for EntryPoint
Sourceimpl PartialEq for EntryPoint
impl PartialEq for EntryPoint
impl StructuralPartialEq for EntryPoint