pub struct Global {
pub section: Section,
pub name: u32,
pub at: GlobalAt,
}Expand description
A GLOBAL record or file of a program that contains others: where the record, or the file’s record area, is in an activation of it.
Fields
section: Sectionname: u32at: GlobalAtTrait Implementations
impl Copy for Global
impl Eq for Global
impl StructuralPartialEq for Global