pub struct HostArray<P = u32> {
pub place: HostPlace<P>,
pub array: Option<Dimension>,
}Expand description
A host variable of a multiple-row statement. A host-variable array’s place is its first
element, and array how far apart its elements and its indicator array’s are; without array
it is one host variable, whose value an INSERT gives every row.
Fields
place: HostPlace<P>array: Option<Dimension>Trait Implementations
impl<P> Eq for HostArray<P>where
P: Eq,
impl<P> StructuralPartialEq for HostArray<P>where
P: PartialEq,