HostPlace

Struct HostPlace 

pub struct HostPlace<P = u32> {
    pub var: P,
    pub member: Option<(u32, u32)>,
    pub ty: Result<HostType, u32>,
    pub indicator: Option<(P, u32)>,
}
A host variable, or one member of a host structure at member’s offset and length. The indicator comes with the offset of this member’s element in it.

Fields

var: Pmember: Option<(u32, u32)>ty: Result<HostType, u32>

Never a structure. An item with no SQL type keeps the walker’s EXEC abend.

indicator: Option<(P, u32)>