pub struct InitPlan {
pub fields: Vec<InitField>,
}Expand description
INITIALIZE of one item: each elementary item the walk reaches, every occurrence listed, with FILLER and its phrases’ choice of receivers and senders made. A reference-modified item is one field, which is the item as located.
Fields
fields: Vec<InitField>Trait Implementations
impl Eq for InitPlan
impl StructuralPartialEq for InitPlan