pub struct JsonGenerate {
pub from: u32,
pub subscripts: Vec<IntExpr>,
pub nodes: Vec<JsonNode>,
pub name: Option<u32>,
pub receiver: u32,
pub encoding: Ccsid,
pub count: Option<(u32, StorePlan)>,
pub code: (u32, StorePlan),
pub on_exception: bool,
pub not_on_exception: bool,
}Expand description
JSON GENERATE. In order: FROM is located, its subscripts evaluated, which begin the walk’s
subscripts (IntExpr::Walk), and the tree walked from nodes[0]; then the receiver is located,
the encoding read, the document written, COUNT IN and JSON-CODE stored.
Fields
from: u32FROM, or its table’s first element when it names the whole table.
subscripts: Vec<IntExpr>nodes: Vec<JsonNode>nodes[0] is FROM, with occurs when FROM names a whole table.
name: Option<u32>The name the document wraps FROM’s value in, as a JSON string; None for NAME … OMITTED.
receiver: u32encoding: Ccsidcount: Option<(u32, StorePlan)>code: (u32, StorePlan)on_exception: boolnot_on_exception: boolTrait Implementations
Sourceimpl Clone for JsonGenerate
impl Clone for JsonGenerate
Sourcefn clone(&self) -> JsonGenerate
fn clone(&self) -> JsonGenerate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for JsonGenerate
impl Debug for JsonGenerate
Sourceimpl Decode for JsonGenerate
impl Decode for JsonGenerate
fn decode(r: &mut Reader<'_>) -> Result<JsonGenerate, ModuleError>
impl Eq for JsonGenerate
Sourceimpl PartialEq for JsonGenerate
impl PartialEq for JsonGenerate
impl StructuralPartialEq for JsonGenerate