pub struct Paragraph {
pub name: u32,
pub is_section: bool,
pub entry: u32,
pub section_end: u32,
pub priority: u8,
pub at: u32,
pub abandoned: Option<u32>,
}Fields
name: u32is_section: boolentry: u32section_end: u32The last paragraph of its section.
priority: u8Its section’s priority-number, 0 for none; 50 or more is an independent segment.
at: u32abandoned: Option<u32>On a paragraph that ends a range: the IRONWORK abend when control passes its end while it holds the return point of a frame control left that cannot resume (C99).