pub struct ParseNode {
pub offset: u32,
pub moved: Vec<Odo>,
pub len: u32,
pub kind: Kind,
pub name: Named,
pub occurs: Option<Count>,
pub ignored: bool,
pub indicator: Option<Indicator>,
pub null: Option<(Figurative, MovePlan)>,
pub value: ParseValue,
}Expand description
As JsonNode, a member’s moved counted as its pair is reached, unless SUPPRESS names it. Each
item takes a value in this order: a second value at the same item and offset is a duplicate;
indicator; then a null goes to null’s MOVE, or is ignored, or is a status; an object fills a
group’s members; any other value goes to a leaf.
Fields
offset: u32moved: Vec<Odo>len: u32kind: Kindname: Namedoccurs: Option<Count>ignored: boolIGNORING JSON NULL FOR the item.
indicator: Option<Indicator>null: Option<(Figurative, MovePlan)>CONVERTING … FROM JSON NULL: the figurative constant and its MOVE into the item.
value: ParseValueTrait Implementations
impl Eq for ParseNode
impl StructuralPartialEq for ParseNode