pub struct PlaceNumcheck {
pub lax: Option<LaxRedefinition>,
pub removed: bool,
}Expand description
NUMCHECK’s facts of a reference, fixed when compiled (compile::numcheck): under ZON(LAX), what
its item may hold because of the item its record redefines; and whether the compiler removed
the test where this reference reads the item, having found it always fails.
Fields
lax: Option<LaxRedefinition>removed: boolTrait Implementations
Sourceimpl Clone for PlaceNumcheck
impl Clone for PlaceNumcheck
Sourcefn clone(&self) -> PlaceNumcheck
fn clone(&self) -> PlaceNumcheck
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PlaceNumcheck
Sourceimpl Debug for PlaceNumcheck
impl Debug for PlaceNumcheck
Sourceimpl Decode for PlaceNumcheck
impl Decode for PlaceNumcheck
fn decode(r: &mut Reader<'_>) -> Result<PlaceNumcheck, ModuleError>
Sourceimpl Default for PlaceNumcheck
impl Default for PlaceNumcheck
Sourcefn default() -> PlaceNumcheck
fn default() -> PlaceNumcheck
Returns the “default value” for a type. Read more
impl Eq for PlaceNumcheck
Sourceimpl PartialEq for PlaceNumcheck
impl PartialEq for PlaceNumcheck
impl StructuralPartialEq for PlaceNumcheck