ReportWriter

Struct ReportWriter 

pub struct ReportWriter<X = Comparand, C = u32, V = u32, U = u32> {
    pub reports: Vec<Report<X, C, V, U>>,
    pub print_switch: Option<usize>,
}
The reports of one program. Items (usize) are data items: by their index in the interpreter, and once lowered by the id of a static place in the slab.

Fields

reports: Vec<Report<X, C, V, U>>print_switch: Option<usize>

PRINT-SWITCH, which SUPPRESS PRINTING sets.