pub struct Resume {
pub para: u32,
pub block: u32,
}Expand description
The statement after an out-of-line PERFORM that runs once and is a statement of paragraph
para: block, where control resumes when it passes that PERFORM’s return point after
leaving its range. block also keys what the PERFORM displaced.
Fields
para: u32block: u32Trait Implementations
impl Copy for Resume
impl Eq for Resume
impl StructuralPartialEq for Resume