pub struct Sequence {
pub positions: Box<[u8; 256]>,
pub characters: Vec<u8>,
pub high_value: u8,
pub low_value: u8,
}Expand description
positions gives each byte’s position from 0, where characters that collate equal share one;
characters the first character given each position, which FUNCTION CHAR returns.
Fields
positions: Box<[u8; 256]>characters: Vec<u8>high_value: u8The last character of the highest position and the first of the lowest.
low_value: u8Trait Implementations
impl Eq for Sequence
impl StructuralPartialEq for Sequence