Module loader

Module loader 

The interpreter’s program loader: the programs CALL can reach, read from source and compiled the first time one is called.

Structs

Library
Where CALL finds programs: the other programs of the first program’s source, then program libraries searched by member name.

Traits

AddProgram
Adding a program to the interpreter’s run unit by its source’s PROGRAM-ID and FILE-CONTROL.