pub struct SourceFile {
pub root: u32,
pub path: String,
pub sha256: [u8; 32],
pub bytes: u64,
}Expand description
A file the compile read, as the run journal of a run of its source names it (load-module.md
9.2): the library it was found in, 0 the source’s own directory and then each -I in order,
its path from there, and its SHA-256 and length.
Fields
root: u32path: Stringsha256: [u8; 32]bytes: u64Trait Implementations
Sourceimpl Clone for SourceFile
impl Clone for SourceFile
Sourcefn clone(&self) -> SourceFile
fn clone(&self) -> SourceFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SourceFile
impl Debug for SourceFile
Sourceimpl Decode for SourceFile
impl Decode for SourceFile
fn decode(r: &mut Reader<'_>) -> Result<SourceFile, ModuleError>
impl Eq for SourceFile
Sourceimpl PartialEq for SourceFile
impl PartialEq for SourceFile
impl StructuralPartialEq for SourceFile