pub struct Picture {
pub category: Category,
pub size: u32,
pub digits: u32,
pub scale: u32,
pub signed: bool,
pub edit: Option<Vec<Sym>>,
pub scaling: u32,
pub currency: Option<String>,
}Fields
category: Categorysize: u32Character positions: bytes for alphanumeric, digits for numeric, characters for national.
digits: u32scale: u32signed: booledit: Option<Vec<Sym>>scaling: u32Scaling positions P to the right of the digits: the value is the digits times ten to this
power. Ps to the left of the digits raise scale past digits instead.
currency: Option<String>The currency sign value its currency symbol stands for.