Group

Struct Group 

pub struct Group {
    pub name: Option<String>,
    pub kind: GroupKind,
    pub level: usize,
    pub next_group: Option<NextGroup>,
    pub lines: Vec<Line>,
    pub unprinted: Vec<Field>,
    pub cross: Vec<(usize, Origin)>,
    pub rolls: Vec<(usize, Origin)>,
    pub totals: Vec<usize>,
    pub indicate: Option<usize>,
    pub declarative: Option<(usize, usize)>,
}

Fields

name: Option<String>kind: GroupKindlevel: usize

The control level of a CONTROL HEADING or FOOTING.

next_group: Option<NextGroup>lines: Vec<Line>unprinted: Vec<Field>

Fields with no COLUMN, which are set but not printed.

cross: Vec<(usize, Origin)>

Cross-footing: SUM entries of this group adding entries of this group, in dependency order.

rolls: Vec<(usize, Origin)>

Rolling forward: SUM entries elsewhere adding entries of this group.

totals: Vec<usize>

The SUM entries defined in this group, reset after it unless RESET defers them.

indicate: Option<usize>declarative: Option<(usize, usize)>

The USE BEFORE REPORTING section: its first and last paragraph.