region

Function region 

pub fn region(
    data: &[u8],
    before: Option<&[u8]>,
    after: Option<&[u8]>,
) -> (usize, usize)
The region [start, end) of data that BEFORE and AFTER INITIAL leave: BEFORE ends it at the first occurrence of its value, AFTER starts it after the first occurrence of its value (or leaves nothing when the value does not occur).