Compiled

Struct Compiled 

pub struct Compiled {
    pub program: Program,
    pub layout: Layout,
    pub options: Options,
    pub ssrange: bool,
}

Fields

program: Programlayout: Layoutoptions: Optionsssrange: bool

Implementations

Source

impl Compiled

pub fn run( &self, out: &mut dyn Write, err: &mut dyn Write, ) -> Result<Ending, Abend>

pub fn run_with( &self, dds: Dds, out: &mut dyn Write, err: &mut dyn Write, ) -> Result<Ending, Abend>

Runs with the DDs that ASSIGN names map to.

pub fn execute<'w>( &self, library: Library, dds: Dds, sysin: Option<Box<dyn BufRead + 'w>>, clock: Clock, out: &'w mut dyn Write, err: &'w mut dyn Write, ) -> Result<(Ending, i16), Abend>

Runs as the first program of a run unit: CALL finds other programs in library, ACCEPT reads sysin. Returns how the run ended and RETURN-CODE.

Source

impl Compiled

pub fn execute_cics<'w>( &self, library: Library, dds: Dds, task: Task, clock: Clock, out: &'w mut dyn Write, err: &'w mut dyn Write, ) -> Result<(Ending, Task), Abend>

Runs as the first program of a CICS task. task says who started it, what COMMAREA it starts with, and what files and queues it has. Returns how the run ended and the task, with RETURN TRANSID and COMMAREA if it ended that way.