execute

Function execute 

pub fn execute<'w>(
    compiled: &Compiled,
    code: &Code,
    library: Library,
    dds: Dds,
    sysin: Option<Box<dyn BufRead + 'w>>,
    clock: Clock,
    database: Option<&'w mut (dyn Database + '_)>,
    out: &'w mut dyn Write,
    err: &'w mut dyn Write,
    observer: Option<Observer<'w>>,
    passed: Passed<'_>,
    kept: &mut Option<Remains>,
) -> Result<(Ending, i16), Halt>
Runs compiled, lowered as code, as the first program of a run unit on the VM, given passed as Execute::execute_main and Execute::execute_with_arguments take it; kept takes what the run left in its run unit.