execute_module

Function execute_module 

pub fn execute_module<'w>(
    module: LoadedModule,
    path: &Path,
    library: Library,
    dds: Dds,
    sysin: Option<Box<dyn BufRead + 'w>>,
    clock: Clock,
    database: Option<&'w mut (dyn Database + '_)>,
    out: &'w mut dyn Write,
    err: &'w mut dyn Write,
    observer: Option<Observer<'w>>,
    parm: Option<&str>,
) -> Result<(Ending, i16), Halt>
Runs program 0 of module, read from path, as the first program of a run unit on the VM, with a job step’s parm, telling observer what the run does. CALL finds the module’s other programs before any other, then as VmLibrary finds them in library’s directories.