pub fn module_program(
module: &LoadedModule,
path: &Path,
library: Library,
name: &str,
) -> Result<Vec<(String, Option<SourceFile>)>, String>Expand description
Whether a CICS task of a run that began with module can begin with the program name, as a
CALL of it finds one, and if so the files a module records for it (LoadedProgram::recorded);
Err says why not.