pub enum Binding {
External {
name: u32,
size: u32,
},
ExternalFile(u16),
Global {
program: u32,
section: Section,
name: u32,
},
}Expand description
Where a record addressed as a LINKAGE record gets its address when the program is activated.
Variants
External
The run unit’s EXTERNAL record of this name and size, allocated by the first program that describes it.
ExternalFile(u16)
The run unit’s record area of EXTERNAL file k, by the file’s name and its area’s size.
Global
What containing program program gives as its GLOBAL name of section: a record, or for
Section::File the record area of the file of that name.