pub struct JsonNode {
pub offset: u32,
pub len: u32,
pub kind: Kind,
pub name: u32,
pub occurs: Option<Count>,
pub value: JsonValue,
}Expand description
An item of the tree, offset bytes into the occurrence of the node that holds it, len its
size; a table’s elements are len apart, occurs of them. name is a member’s JSON string.
Fields
offset: u32len: u32kind: Kindname: u32occurs: Option<Count>value: JsonValueTrait Implementations
impl Eq for JsonNode
impl StructuralPartialEq for JsonNode