pub struct Library {
pub programs: Vec<Program>,
pub dirs: Vec<PathBuf>,
pub copy: Libraries,
pub flags: Vec<String>,
}Expand description
Where CALL finds programs: the other programs of the first program’s source, then program libraries searched by member name.
Fields
programs: Vec<Program>dirs: Vec<PathBuf>copy: Librariesflags: Vec<String>Trait Implementations
Sourceimpl Loader<Rc<Compiled>> for Library
impl Loader<Rc<Compiled>> for Library
Sourcefn program(
&mut self,
name: &str,
) -> Result<LoadedProgram<Rc<Compiled>>, LoadError>
fn program( &mut self, name: &str, ) -> Result<LoadedProgram<Rc<Compiled>>, LoadError>
The program whose PROGRAM-ID CALL names, compiled.
Sourcefn holder(&self, entry: &str) -> Option<String>
fn holder(&self, entry: &str) -> Option<String>
The PROGRAM-ID of a program not yet loaded that has an ENTRY of this name.
Sourcefn entry(program: &Rc<Compiled>, name: &str) -> Option<usize>
fn entry(program: &Rc<Compiled>, name: &str) -> Option<usize>
Which of a loaded program’s ENTRY statements has this name.