pub fn lower(compiled: &Compiled) -> Result<Program, LowerError>Expand description
Lowers one compiled program, or a class definition with its data and methods. One that passes Check and uses only the constructs lowered so far lowers.
pub fn lower(compiled: &Compiled) -> Result<Program, LowerError>Lowers one compiled program, or a class definition with its data and methods. One that passes Check and uses only the constructs lowered so far lowers.