pub trait Database {
// Required methods
fn execute(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>;
fn prepare(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>;
fn open(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>;
fn fetch(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>;
fn close(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>;
fn commit(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>;
fn rollback(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>;
// Provided method
fn close_all(&mut self) -> Result<(), Abandoned> { ... }
}Required Methods
Sourcefn execute(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
fn execute(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
SELECT INTO, SET, VALUES INTO, INSERT, UPDATE and DELETE, and a dynamic statement that is not a query.
Sourcefn prepare(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
fn prepare(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
Checks a statement string PREPARE names, which then runs through execute or open.
fn open(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
Sourcefn fetch(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
fn fetch(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
One row, or no row at the end.
fn close(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
fn commit(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
fn rollback(&mut self, call: &Call<'_>) -> Result<Outcome, Abandoned>
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".