Abend

Struct Abend 

pub struct Abend {
    pub code: AbendCode,
    pub message: String,
    pub pos: Pos,
    pub file: Option<String>,
}

Fields

code: AbendCodemessage: Stringpos: Posfile: Option<String>

The source the abend is in, named by the innermost program or method it left: a library file by path, otherwise from its source table, where the first program’s source is empty. None for an abend in the first program.

Implementations

Source

impl Abend

pub fn check(c: ProgramCheck, pos: Pos) -> Abend

pub fn ironwork(message: impl Into<String>, pos: Pos) -> Abend