Compiled

Struct Compiled 

pub struct Compiled {
    pub program: Program,
    pub when_compiled: CompileTime,
    pub layout: Layout,
    pub options: Options,
    pub ssrange: bool,
    pub report_writer: Writer<Expr, Ref, Literal, (usize, usize)>,
    pub collating: Sequence,
    pub carriage: Vec<Option<Carriage>>,
    pub diagnostics: Vec<Error>,
    pub entries: Vec<EntryPoint>,
    pub declaratives: Table,
    pub functions: Vec<Udf>,
}

Fields

program: Programwhen_compiled: CompileTime

FUNCTION WHEN-COMPILED’s time.

layout: Layoutoptions: Optionsssrange: boolreport_writer: Writer<Expr, Ref, Literal, (usize, usize)>collating: Sequence

The PROGRAM COLLATING SEQUENCE, or EBCDIC.

carriage: Vec<Option<Carriage>>

Each file’s printer control character, when it is a print file.

diagnostics: Vec<Error>

The messages of a program that compiled, none of them severe enough to stop its object code.

entries: Vec<EntryPoint>

The program’s ENTRY statements, in source order.

declaratives: Table

Where each EXCEPTION/ERROR and debugging procedure runs.

functions: Vec<Udf>

The user-defined functions the program may invoke.