pub fn execute<'w>(
compiled: &Compiled,
code: &Code,
library: Library,
dds: Dds,
sysin: Option<Box<dyn BufRead + 'w>>,
clock: Clock,
database: Option<&'w mut (dyn Database + '_)>,
out: &'w mut dyn Write,
err: &'w mut dyn Write,
observer: Option<Observer<'w>>,
parm: Option<&str>,
kept: &mut Option<Remains>,
) -> Result<(Ending, i16), Halt>Expand description
Runs compiled, lowered as code, as the first program of a run unit on the VM, with a job
step’s parm as Execute::execute_main takes it; kept takes what the run left in its run
unit.